@@ -1,5 +1,7 @@
 from dataclasses import dataclass
+from datetime import datetime
 from enum import Enum, auto
+from typing import Optional
 
 
 class FilterType(Enum):
@@ -9,12 +11,15 @@ class FilterType(Enum):
     ENTIRE_MATCH_NOT = auto()
     NONE = auto()
 
+
 @dataclass(frozen=True)
 class FilterCond:
     type: FilterType
     values: [str]
 
-    def filter(self, value: str) -> bool:
+    def filter(self, value: Optional[str]) -> bool:
+        if value is None:
+            return False
         if self.type == FilterType.PARTIAL_MATCH:
             return any(v in value for v in self.values)
         elif self.type == FilterType.PARTIAL_MATCH_NOT:
@@ -37,8 +42,33 @@ class FilterCond:
         else:
             return self
 
+
 FILTER_NONE = FilterCond(FilterType.NONE, [])
 
+
+@dataclass(frozen=True)
+class DateFilter:
+    years: [int]
+    months: [int]
+    days: [int]
+
+    def filter(self, time: datetime):
+        """
+        Examples:
+            >>> DATE_FILTER_NONE.filter(datetime.now())
+            True
+        """
+        if self.years and time.year not in self.years:
+            return False
+        if self.months and time.month not in self.months:
+            return False
+        if self.days and time.day not in self.days:
+            return False
+        return True
+
+
+DATE_FILTER_NONE = DateFilter([], [], [])
+
+
 def gen_filter(args: [str]):
     return FilterCond(FilterType.PARTIAL_MATCH, args) if args else FILTER_NONE
-
